summaryrefslogtreecommitdiff
path: root/src/data
diff options
context:
space:
mode:
authorxCrystal <rgr.crystal@gmail.com>2016-01-17 12:14:56 +0100
committerxCrystal <rgr.crystal@gmail.com>2016-01-17 12:14:56 +0100
commit4dc29d4884eeb2e4bc7be34588f4408db9f8008c (patch)
tree12cf0ab489fa63f5fea90576da803f3359f50e63 /src/data
parent95c6b2390120a95c77e4bf582452ec77f426976a (diff)
Generalize to "effect commands", even for trainer cards, to avoid confusion
Diffstat (limited to 'src/data')
-rw-r--r--src/data/effect_commands.asm (renamed from src/data/move_card_effects.asm)6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/data/move_card_effects.asm b/src/data/effect_commands.asm
index 04b5a00..38e4dc5 100644
--- a/src/data/move_card_effects.asm
+++ b/src/data/effect_commands.asm
@@ -1,8 +1,8 @@
-MoveEffectAndTrainerCardCommands: ; 186f7 (6:46f7)
+EffectCommands: ; 186f7 (6:46f7)
; Each move has a two-byte effect pointer (move's 7th param) that points to one of these structures.
; Similarly, trainer cards have a two-byte pointer (7th param) to one of these structures, which determines the card's function.
; Energy cards also point to one of these, but their data is just $00.
-; db CommandId ($01 - $09)
+; db CommandId ($01 - $0a)
; dw Function
; ...
; db $00
@@ -13,7 +13,7 @@ MoveEffectAndTrainerCardCommands: ; 186f7 (6:46f7)
; Similar move effects of different Pokemon cards all point to a different command list,
; even though in some cases their commands and function pointers match.
; xxx use <TrainerCardName>FunctionCommands or <EnergyCardName>FunctionCommands for these types of cards.
EkansSpitPoisonEffectCommands:
dbw $03, $46F8
@@ -13,7 +13,7 @@ MoveEffectAndTrainerCardCommands: ; 186f7 (6:46f7)
; Similar move effects of different Pokemon cards all point to a different command list,
; even though in some cases their commands and function pointers match.
-; xxx use <TrainerCardName>FunctionCommands or <EnergyCardName>FunctionCommands for these types of cards.
+; xxx use <TrainerCardName>EffectCommands or <EnergyCardName>EffectCommands for these types of cards.
EkansSpitPoisonEffectCommands:
dbw $03, $46F8